/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl;

import java.util.List;

import org.ow2.util.ee.metadata.common.api.ICommonClassMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonFieldMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonMethodMetadata;
import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationResource;
import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationSqlDataSourceDefinition;
import org.ow2.util.ee.metadata.common.api.struct.IJEjbEJB;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceContext;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceUnit;
import org.ow2.util.ee.metadata.common.api.struct.IJaxwsWebServiceRef;
import org.ow2.util.ee.metadata.common.api.struct.IJwsHandlerChain;
import org.ow2.util.scan.api.metadata.ClassMetadata;

/**
 * EZB common class metadata.
 * @author Gael Lalire
 * @param <C> class type
 * @param <M> method type
 * @param <F> field type
 */
public class CommonClassMetadata<
    C extends ICommonClassMetadata<C, M, F>,
    M extends ICommonMethodMetadata<C, M, F>,
    F extends ICommonFieldMetadata<C, M, F>>
        extends ClassMetadata<C, M, F> implements ICommonClassMetadata<C, M, F> {

    /**
     * Environnement accessor.
     */
    private AbsEnvironmentRefAccessor environmentRefAccessor;

    /**
     * The run-as security role (if any).
     */
    private String runAs = null;

    /**
     * The ManagedBean name (if any).
     */
    private String managedBeanName = null;

    /**
     * No-arg Constructor.
     */
    protected CommonClassMetadata() {
        super();
        this.environmentRefAccessor = new AbsEnvironmentRefAccessor();
    }

    public AbsEnvironmentRefAccessor getEnvironmentRefAccessor() {
        return environmentRefAccessor;
    }

    /**
     * @return JEjbEJB object representing javax.ejb.EJB annotation.
     */
    public final IJEjbEJB getJEjbEJB() {
        return this.environmentRefAccessor.getJEjbEJB();
    }

    /**
     * Set JAnnotationEJB object.
     * @param jEjbEJB object representing javax.annotation.EJB annotation.
     */
    public final void setJEjbEJB(final IJEjbEJB jEjbEJB) {
        this.environmentRefAccessor.setJEjbEJB(jEjbEJB);
    }

    /**
     * @return JAnnotationResource object representing javax.annotation.Resource
     *         annotation.
     */
    public final IJAnnotationResource getJAnnotationResource() {
        return this.environmentRefAccessor.getJAnnotationResource();
    }

    /**
     * Set JAnnotationResource object.
     * @param jAnnotationResource object representing javax.annotation.Resource
     *        annotation.
     */
    public final void setJAnnotationResource(final IJAnnotationResource jAnnotationResource) {
        this.environmentRefAccessor.setJAnnotationResource(jAnnotationResource);
    }

    /**
     * @return true if this field is used as a persistence context.
     */
    public final boolean isPersistenceContext() {
        return this.environmentRefAccessor.isPersistenceContext();
    }

    /**
     * @return the persistence context infos.
     */
    public final IJavaxPersistenceContext getJavaxPersistenceContext() {
        return this.environmentRefAccessor.getJavaxPersistenceContext();
    }

    /**
     * Sets the persistence context info on this field.
     * @param javaxPersistenceContext information on persistence context.
     */
    public final void setJavaxPersistenceContext(final IJavaxPersistenceContext javaxPersistenceContext) {
        this.environmentRefAccessor.setJavaxPersistenceContext(javaxPersistenceContext);
    }

    /**
     * @return true if this field is used as a persistence unit.
     */
    public final boolean isPersistenceUnit() {
        return this.environmentRefAccessor.isPersistenceUnit();
    }

    /**
     * @return the persistence unit infos.
     */
    public final IJavaxPersistenceUnit getJavaxPersistenceUnit() {
        return this.environmentRefAccessor.getJavaxPersistenceUnit();
    }

    /**
     * Sets the persistence unit info on this field.
     * @param javaxPersistenceUnit information on persistence unit.
     */
    public final void setJavaxPersistenceUnit(final IJavaxPersistenceUnit javaxPersistenceUnit) {
        this.environmentRefAccessor.setJavaxPersistenceUnit(javaxPersistenceUnit);
    }

    /**
     * @return jEjbEJBs list representing &#64;{@link javax.ejb.EJBs} annotation.
     */
    public final List<IJEjbEJB> getJEjbEJBs() {
        return this.environmentRefAccessor.getJEjbEJBs();
    }

    /**
     * Set JEjbEJBs object.
     * @param jEjbEJBs list representing javax.ejb.EJBs annotation.
     */
    public final void setJEjbEJBs(final List<IJEjbEJB> jEjbEJBs) {
        this.environmentRefAccessor.setJEjbEJBs(jEjbEJBs);
    }

    /**
     * @return JAnnotationResources list representing &#64;{@link javax.annotation.Resources} annotation.
     */
    public final List<IJAnnotationResource> getJAnnotationResources() {
        return this.environmentRefAccessor.getJAnnotationResources();
    }

    /**
     * Sets JAnnotationResources object.
     * @param jAnnotationResources list representing javax.annotation.Resources annotation.
     */
    public final void setJAnnotationResources(final List<IJAnnotationResource> jAnnotationResources) {
        this.environmentRefAccessor.setJAnnotationResources(jAnnotationResources);
    }

    public List<IJAnnotationSqlDataSourceDefinition> getJAnnotationSqlDataSourceDefinitions() {
        return this.environmentRefAccessor.getJAnnotationSqlDataSourceDefinitions();
    }

    public void setJAnnotationSqlDataSourceDefinitions(
            List<IJAnnotationSqlDataSourceDefinition> jAnnotationSqlDataSourceDefinitions) {
        this.environmentRefAccessor.setJAnnotationSqlDataSourceDefinitions(jAnnotationSqlDataSourceDefinitions);
    }

    /**
     * @return javaxPersistencePersistenceContexts list representing &#64;{@link javax.persistence.PersistenceContexts}
     *         annotation.
     */
    public final List<IJavaxPersistenceContext> getJavaxPersistencePersistenceContexts() {
        return this.environmentRefAccessor.getJavaxPersistencePersistenceContexts();
    }

    /**
     * Sets JavaxPersistencePersistenceContexts object.
     * @param javaxPersistencePersistenceContexts list representing &#64;{@link javax.persistence.PersistenceContexts}
     *        annotation.
     */
    public final void setJavaxPersistencePersistenceContexts(
            final List<IJavaxPersistenceContext> javaxPersistencePersistenceContexts) {
        this.environmentRefAccessor.setJavaxPersistencePersistenceContexts(javaxPersistencePersistenceContexts);
    }

    /**
     * @return javaxPersistencePersistenceUnits list representing &#64;{@link javax.persistence.PersistenceUnits} annotation.
     */
    public final List<IJavaxPersistenceUnit> getJavaxPersistencePersistenceUnits() {
        return this.environmentRefAccessor.getJavaxPersistencePersistenceUnits();
    }

    /**
     * Sets setJavaxPersistencePersistenceUnits object.
     * @param javaxPersistencePersistenceUnits list representing &#64;{@link javax.persistence.PersistenceUnits} annotation.
     */
    public final void setJavaxPersistencePersistenceUnits(final List<IJavaxPersistenceUnit> javaxPersistencePersistenceUnits) {
        this.environmentRefAccessor.setJavaxPersistencePersistenceUnits(javaxPersistencePersistenceUnits);
    }

    /**
     * @return jaxwsWebServiceRefs list representing
     *         &#64;{@link javax.xml.ws.WebServiceRefs} annotation.
     */
    public List<IJaxwsWebServiceRef> getJaxwsWebServiceRefs() {
        return environmentRefAccessor.getJaxwsWebServiceRefs();
    }

    /**
     * Sets jaxwsWebServiceRefs object.
     *
     * @param jaxwsWebServiceRefs list representing
     *                            &#64;{@link javax.xml.ws.WebServiceRefs} annotation.
     */
    public void setJaxwsWebServiceRefs(final List<IJaxwsWebServiceRef> jaxwsWebServiceRefs) {
        environmentRefAccessor.setJaxwsWebServiceRefs(jaxwsWebServiceRefs);
    }

    /**
     * @return IJWebServiceRef object representing javax.xml.ws.WebServiceRef annotation.
     */
    public IJaxwsWebServiceRef getJaxwsWebServiceRef() {
        return environmentRefAccessor.getJaxwsWebServiceRef();
    }

    /**
     * Set JWebServiceRef object.
     *
     * @param wsr object representing javax.xml.ws.WebServiceRef annotation.
     */
    public void setJaxwsWebServiceRef(final IJaxwsWebServiceRef wsr) {
        environmentRefAccessor.setJaxwsWebServiceRef(wsr);
    }

    /**
     * @return IJwsHandlerChain object representing &#64;{@link javax.jws.HandlerChain} annotation.
     */
    public IJwsHandlerChain getJwsHandlerChain() {
        return environmentRefAccessor.getJwsHandlerChain();
    }

    /**
     * Set JwsHandlerChain object.
     *
     * @param jwshandlerChain object representing &#64;{@link javax.jws.HandlerChain} annotation.
     */
    public void setJwsHandlerChain(final IJwsHandlerChain jwshandlerChain) {
        environmentRefAccessor.setJwsHandlerChain(jwshandlerChain);
    }

    /**
     * Set the value of the run-as property.
     * @param runAs the run-as property.
     */
    public void setRunAs(final String runAs) {
        this.runAs = runAs;
    }

    /**
     * @return the name of the security-role of the run-as element.
     */
    public String getRunAs() {
        return this.runAs;
    }

    /**
     * Set the name value of a ManagedBean.
     *
     * @param managedBeanName the ManagedBean name.
     */
    public void setManagedBeanName(String managedBeanName) {
        this.managedBeanName = managedBeanName;
    }

    /**
     * Returns the ManagedBean name or null if class is not annotated with @ManagedBean
     *
     * @return the ManagedBean name or null.
     */
    public String getManagedBeanName() {
        return managedBeanName;
    }

    /**
     * Returns true if class is not annotated with @ManagedBean
     * @return true if class is not annotated with @ManagedBean
     */
    public boolean isManagedBean() {
        return this.getManagedBeanName() != null;
    }

}
