/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl;

import org.ow2.util.ee.metadata.common.api.ICommonClassMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonFieldMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonMethodMetadata;
import org.ow2.util.ee.metadata.common.api.struct.IJAnnotationResource;
import org.ow2.util.ee.metadata.common.api.struct.IJEjbEJB;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceContext;
import org.ow2.util.ee.metadata.common.api.struct.IJavaxPersistenceUnit;
import org.ow2.util.ee.metadata.common.api.struct.IJaxwsWebServiceRef;
import org.ow2.util.ee.metadata.common.api.struct.IJwsHandlerChain;
import org.ow2.util.scan.api.metadata.FieldMetadata;
import org.ow2.util.scan.api.metadata.structures.JField;

/**
 * EZB common field metadata.
 * @author Gael Lalire
 * @param <C> class type
 * @param <M> method type
 * @param <F> field type
 */
public class CommonFieldMetadata<C extends ICommonClassMetadata<C, M, F>, M extends ICommonMethodMetadata<C, M, F>, F extends ICommonFieldMetadata<C, M, F>>
        extends FieldMetadata<C, M, F> implements ICommonFieldMetadata<C, M, F> {

    /**
     * metadata common with class, field and method.
     */
    private AbsSharedMetadata commonMetadata;

    /**
     * Constructor.
     * @param jField signature
     * @param classAnnotationMetadata parent
     */
    protected CommonFieldMetadata(final JField jField, final C classAnnotationMetadata) {
        super(jField, classAnnotationMetadata);
        this.commonMetadata = new AbsSharedMetadata();
    }

    /**
     * @return JEjbEJB object representing javax.ejb.EJB annotation.
     */
    public final IJEjbEJB getJEjbEJB() {
        return this.commonMetadata.getJEjbEJB();
    }

    /**
     * Set JAnnotationEJB object.
     * @param jEjbEJB object representing javax.annotation.EJB annotation.
     */
    public final void setJEjbEJB(final IJEjbEJB jEjbEJB) {
        this.commonMetadata.setJEjbEJB(jEjbEJB);
    }

    /**
     * @return JAnnotationResource object representing javax.annotation.Resource
     *         annotation.
     */
    public final IJAnnotationResource getJAnnotationResource() {
        return this.commonMetadata.getJAnnotationResource();
    }

    /**
     * Set JAnnotationResource object.
     * @param jAnnotationResource object representing javax.annotation.Resource
     *        annotation.
     */
    public final void setJAnnotationResource(final IJAnnotationResource jAnnotationResource) {
        this.commonMetadata.setJAnnotationResource(jAnnotationResource);
    }

    /**
     * @return true if this field is used as a persistence context.
     */
    public final boolean isPersistenceContext() {
        return this.commonMetadata.isPersistenceContext();
    }

    /**
     * @return the persistence context infos.
     */
    public final IJavaxPersistenceContext getJavaxPersistenceContext() {
        return this.commonMetadata.getJavaxPersistenceContext();
    }

    /**
     * Sets the persistence context info on this field.
     * @param javaxPersistenceContext information on persistence context.
     */
    public final void setJavaxPersistenceContext(final IJavaxPersistenceContext javaxPersistenceContext) {
        this.commonMetadata.setJavaxPersistenceContext(javaxPersistenceContext);
    }

    /**
     * @return true if this field is used as a persistence unit.
     */
    public final boolean isPersistenceUnit() {
        return this.commonMetadata.isPersistenceUnit();
    }

    /**
     * @return the persistence unit infos.
     */
    public final IJavaxPersistenceUnit getJavaxPersistenceUnit() {
        return this.commonMetadata.getJavaxPersistenceUnit();
    }

    /**
     * Sets the persistence unit info on this field.
     * @param javaxPersistenceUnit information on persistence unit.
     */
    public final void setJavaxPersistenceUnit(final IJavaxPersistenceUnit javaxPersistenceUnit) {
        this.commonMetadata.setJavaxPersistenceUnit(javaxPersistenceUnit);
    }

    /**
     * @return IJWebServiceRef object representing javax.xml.ws.WebServiceRef
     *         annotation.
     */
    public IJaxwsWebServiceRef getJaxwsWebServiceRef() {
        return commonMetadata.getJaxwsWebServiceRef();
    }

    /**
     * Set JWebServiceRef object.
     * @param wsr object representing javax.xml.ws.WebServiceRef annotation.
     */
    public void setJaxwsWebServiceRef(final IJaxwsWebServiceRef wsr) {
        commonMetadata.setJaxwsWebServiceRef(wsr);
    }

    /**
     * @return IJwsHandlerChain object representing &#64;{@link javax.jws.HandlerChain}
     *         annotation.
     */
    public IJwsHandlerChain getJwsHandlerChain() {
        return commonMetadata.getJwsHandlerChain();
    }

    /**
     * Set JwsHandlerChain object.
     * @param jwshandlerChain object representing &#64;{@link javax.jws.HandlerChain}
     *        annotation.
     */
    public void setJwsHandlerChain(final IJwsHandlerChain jwshandlerChain) {
        commonMetadata.setJwsHandlerChain(jwshandlerChain);
    }
}
