/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.configurator;

import java.util.List;

import org.ow2.util.ee.metadata.common.api.ICommonClassMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonFieldMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonMethodMetadata;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz.JavaxAnnotationManagedBeanVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz.JavaxAnnotationResourcesVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz.JavaxAnnotationSecurityRunAs;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz.JavaxAnnotationSqlDataSourceDefinitionVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz.JavaxAnnotationSqlDataSourceDefinitionsVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz.JavaxEjbEJBsVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz.JavaxPersistencePersistenceContextsVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz.JavaxPersistencePersistenceUnitsVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz.JavaxXmlWsWebServiceRefsVisitor;
import org.ow2.util.scan.api.configurator.metadata.ClassMetadataConfigurator;
import org.ow2.util.scan.api.configurator.metadata.specific.ISpecificArchiveConfigurator;

/**
 * CommonClassMetadataConfigurator.
 * @author Gael Lalire
 * @param <C> class type
 * @param <M> method type
 * @param <F> field type
 */
public abstract class CommonClassMetadataConfigurator<
    C extends ICommonClassMetadata<C, M, F>,
    M extends ICommonMethodMetadata<C, M, F>,
    F extends ICommonFieldMetadata<C, M, F>>
        extends ClassMetadataConfigurator<C, M, F> {

    /**
     * Constructor.
     * @param classMetadata classMetadata
     * @param specificArchiveConfiguratorList specific archive configurator list
     */
    public CommonClassMetadataConfigurator(final C classMetadata,
            final List<? extends ISpecificArchiveConfigurator<C, M, F>> specificArchiveConfiguratorList) {
        super(classMetadata, specificArchiveConfiguratorList);
    }

    /**
     * register annotation visitor.
     */
    protected void registerAnnotationVisitor() {

        C classMetadata = getClassMetadata();

        // add visitor shared with class and field and method
        CommonMetadataConfigurator.initVisitor(getAnnotationVisitors(), classMetadata);

        // add @EJBs
        getAnnotationVisitors().put(JavaxEjbEJBsVisitor.TYPE,
                new JavaxEjbEJBsVisitor(classMetadata));

        // add @Resources
        getAnnotationVisitors().put(JavaxAnnotationResourcesVisitor.TYPE,
                new JavaxAnnotationResourcesVisitor(classMetadata));

        // add @DataSourceDefinition
        getAnnotationVisitors().put(JavaxAnnotationSqlDataSourceDefinitionVisitor.TYPE,
                new JavaxAnnotationSqlDataSourceDefinitionVisitor<C, M, F>(classMetadata));

        // add @DataSourceDefinitions
        getAnnotationVisitors().put(JavaxAnnotationSqlDataSourceDefinitionsVisitor.TYPE,
                new JavaxAnnotationSqlDataSourceDefinitionsVisitor<C, M, F>(classMetadata));

        // add @PersistenceContexts
        getAnnotationVisitors().put(JavaxPersistencePersistenceContextsVisitor.TYPE,
                new JavaxPersistencePersistenceContextsVisitor(classMetadata));

        // add @PersistenceUnits
        getAnnotationVisitors().put(JavaxPersistencePersistenceUnitsVisitor.TYPE,
                new JavaxPersistencePersistenceUnitsVisitor(classMetadata));

        // add @WebServiceRefs
        getAnnotationVisitors().put(JavaxXmlWsWebServiceRefsVisitor.TYPE,
                                    new JavaxXmlWsWebServiceRefsVisitor(classMetadata));

        // add @RunAs
        getAnnotationVisitors().put(JavaxAnnotationSecurityRunAs.TYPE,
                new JavaxAnnotationSecurityRunAs<C, M, F>(classMetadata));

         // add @RunAs
        getAnnotationVisitors().put(JavaxAnnotationManagedBeanVisitor.TYPE,
                new JavaxAnnotationManagedBeanVisitor<C, M, F>(classMetadata));

    }

}
