/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.configurator;

import java.util.Map;

import org.ow2.util.ee.metadata.common.api.interfaces.ISharedMetadata;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.JavaxAnnotationResourceVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.JavaxEjbEJBVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.JavaxJwsHandlerChainVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.JavaxPersistencePersistenceContextVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.JavaxPersistencePersistenceUnitVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.JavaxXmlWsWebServiceRefVisitor;
import org.ow2.util.scan.api.IAnnotationVisitor;

/**
 * Utility class.
 * @author Gael Lalire
 */
public final class CommonMetadataConfigurator {

    /**
     * Constructor.
     */
    private CommonMetadataConfigurator() {
    }

    /**
     * @param <T> type
     * @param annotationVisitors annotationVisitors
     * @param annotationMetadata am
     */
    public static <T extends ISharedMetadata> void initVisitor(final Map<String, IAnnotationVisitor> annotationVisitors,
            final T annotationMetadata) {

        // add @EJB
        annotationVisitors.put(JavaxEjbEJBVisitor.TYPE, new JavaxEjbEJBVisitor<T>(annotationMetadata));

        // add @Resource
        annotationVisitors.put(JavaxAnnotationResourceVisitor.TYPE, new JavaxAnnotationResourceVisitor<T>(annotationMetadata));

        // add @PersistenceContext
        annotationVisitors.put(JavaxPersistencePersistenceContextVisitor.TYPE, new JavaxPersistencePersistenceContextVisitor<T>(
                annotationMetadata));

        // add @PersistenceUnit
        annotationVisitors.put(JavaxPersistencePersistenceUnitVisitor.TYPE, new JavaxPersistencePersistenceUnitVisitor<T>(
                annotationMetadata));

        // add @WebServiceRef
        annotationVisitors.put(JavaxXmlWsWebServiceRefVisitor.TYPE,
                               new JavaxXmlWsWebServiceRefVisitor<T>(annotationMetadata));

        // add @HandlerChain
        annotationVisitors.put(JavaxJwsHandlerChainVisitor.TYPE,
                               new JavaxJwsHandlerChainVisitor<T>(annotationMetadata));

    }

}
