/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.configurator;

import java.util.List;

import org.ow2.util.ee.metadata.common.api.ICommonClassMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonFieldMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonMethodMetadata;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.method.JavaxAnnotationPostConstructVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.method.JavaxAnnotationPreDestroyVisitor;
import org.ow2.util.scan.api.configurator.metadata.MethodMetadataConfigurator;
import org.ow2.util.scan.api.configurator.metadata.specific.ISpecificClassConfigurator;

/**
 * CommonFieldMetadataConfigurator.
 * @author Gael Lalire
 * @param <C> class type
 * @param <M> method type
 * @param <F> field type
 */
public abstract class CommonMethodMetadataConfigurator<
    C extends ICommonClassMetadata<C, M, F>,
    M extends ICommonMethodMetadata<C, M, F>,
    F extends ICommonFieldMetadata<C, M, F>>
        extends MethodMetadataConfigurator<C, M, F> {

    /**
     * Constructor.
     * @param methodMetadata methodMetadata
     * @param specificClassConfiguratorList list
     */
    public CommonMethodMetadataConfigurator(final M methodMetadata,
            final List<ISpecificClassConfigurator<C, M, F>> specificClassConfiguratorList) {
        super(methodMetadata, specificClassConfiguratorList);
    }

    /**
     * register annotation visitor.
     */
    protected void registerAnnotationVisitor() {

        M methodMetadata = getMethodMetadata();

        // add visitor shared with class and field and method
        CommonMetadataConfigurator.initVisitor(getAnnotationVisitors(), methodMetadata);

        // add @PostConstruct
        getAnnotationVisitors().put(JavaxAnnotationPostConstructVisitor.TYPE,
                new JavaxAnnotationPostConstructVisitor(methodMetadata));
        // add @PreDestroy
        getAnnotationVisitors().put(JavaxAnnotationPreDestroyVisitor.TYPE,
                new JavaxAnnotationPreDestroyVisitor(methodMetadata));


    }


}
