/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.configurator.visitor;

import org.ow2.util.scan.api.IAnnotationVisitor;
import org.ow2.util.scan.api.IType;


/**
 * This class manages the setter/getter of annotation visitor.
 * @param <T> a metadata object.
 * @author Florent Benoit
 */
public abstract class AbsAnnotationVisitor<T> implements IAnnotationVisitor, AnnotationType {

    /**
     * Linked to an AnnotationMetadata ?
     */
    private T annotationMetadata;

    /**
     * Constructor (default).
     */
    public AbsAnnotationVisitor() {

    }

    /**
     * Constructor.
     * @param annotationMetadata linked to an annotation metadata
     */
    public AbsAnnotationVisitor(final T annotationMetadata) {
        this();
        this.annotationMetadata = annotationMetadata;
    }

    /**
     * Visits a primitive value of the annotation.
     * @param name the value name.
     * @param value the actual value, whose type must be {@link Byte},
     *        {@link Boolean}, {@link Character}, {@link Short},
     *        {@link Integer}, {@link Long}, {@link Float}, {@link Double},
     *        {@link String} or {@link IType}.
     */
    public void visit(final String name, final Object value) {

    }

    /**
     * Visits an enumeration value of the annotation.
     * @param name the value name.
     * @param desc the class descriptor of the enumeration class.
     * @param value the actual enumeration value.
     */
    public void visitEnum(final String name, final String desc, final String value) {

    }

    /**
     * Visits a nested annotation value of the annotation.
     * @param name the value name.
     * @param desc the class descriptor of the nested annotation class.
     * @return a non null visitor to visit the actual nested annotation value.
     *         <i>The nested annotation value must be fully visited before
     *         calling other methods on this annotation visitor</i>.
     */
    public IAnnotationVisitor visitAnnotation(final String name, final String desc) {
        return this;
    }

    /**
     * Visits an array value of the annotation.
     * @param name the value name.
     * @return a non null visitor to visit the actual array value elements. The
     *         'name' parameters passed to the methods of this visitor are
     *         ignored. <i>All the array values must be visited before calling
     *         other methods on this annotation visitor</i>.
     */
    public IAnnotationVisitor visitArray(final String name) {
        return this;
    }

    /**
     * Visits the end of the annotation.
     */
    public abstract void visitEnd();


    /**
     * @return class/method metadata
     */
    public T getAnnotationMetadata() {
        return this.annotationMetadata;
    }



}
