/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.configurator.visitor;

import org.ow2.util.scan.api.IAnnotationVisitor;

/**
 * This class manages the handling of enum values.
 * @param <T> the ClassAnnotationMetadata or MethodAnnotationMetadata.
 * @author Florent Benoit
 */
public abstract class EnumAnnotationVisitor<T> extends AbsAnnotationVisitor<T> implements IAnnotationVisitor, AnnotationType {

    /**
     * Value.
     */
    private String value = null;


    /**
     * Constructor.
     * @param annotationMetadata linked to a &lt;T&gt; metadata.
     */
    public EnumAnnotationVisitor(final T annotationMetadata) {
        super(annotationMetadata);
    }

    /**
     * Visits an enumeration value of the annotation.
     * @param name the value name.
     * @param desc the class descriptor of the enumeration class.
     * @param value the actual enumeration value.
     */
    @Override
    public void visitEnum(final String name, final String desc, final String value) {
        this.value = value;
    }

    /**
     * @return value of the object
     */
    public String getValue() {
        return this.value;
    }


}
