/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.configurator.visitor;

import java.util.ArrayList;
import java.util.List;

import org.ow2.util.ee.metadata.common.api.interfaces.IAnnotationSecurityRolesAllowed;

/**
 * This class manages the handling of &#64;{@link javax.annotation.security.DeclareRoles}
 * annotation.
 * @param <T> An implementation of IAnnotationSecurityRolesAllowed interface.
 * @author Florent Benoit
 */
public class JavaxAnnotationSecurityRolesAllowedVisitor<T extends IAnnotationSecurityRolesAllowed> extends
        ObjectArrayAnnotationVisitor<T, String> implements AnnotationType {

    /**
     * Type of annotation.
     */
    public static final String TYPE = "Ljavax/annotation/security/RolesAllowed;";

    /**
     * Constructor.
     * @param annotationMetadata linked to a class/method metadata
     */
    public JavaxAnnotationSecurityRolesAllowedVisitor(final T annotationMetadata) {
        super(annotationMetadata);
    }

    /**
     * Visits the end of the annotation. <br>
     * Creates the object and store it.
     */
    @Override
    public void visitEnd() {
        List<String> rolesAllowed = new ArrayList<String>();
        for (String s : getArrayObjects()) {
            rolesAllowed.add(s);
        }
        getAnnotationMetadata().setRolesAllowed(rolesAllowed);
    }

    /**
     * @return type of the annotation (its description)
     */
    public String getType() {
        return TYPE;
    }

}
