/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.configurator.visitor;

import static javax.ejb.TransactionAttributeType.MANDATORY;
import static javax.ejb.TransactionAttributeType.NEVER;
import static javax.ejb.TransactionAttributeType.NOT_SUPPORTED;
import static javax.ejb.TransactionAttributeType.REQUIRED;
import static javax.ejb.TransactionAttributeType.REQUIRES_NEW;
import static javax.ejb.TransactionAttributeType.SUPPORTS;

import org.ow2.util.ee.metadata.common.api.interfaces.ITransactionAttribute;

/**
 * This class manages the handling of &#64;{@link javax.ejb.TransactionAttribute} annotation.
 * @param <T> An implementation of ITransactionAttribute interface.
 * @author Florent Benoit
 */
public class JavaxEjbTransactionAttributeVisitor<T extends ITransactionAttribute>
          extends EnumAnnotationVisitor<T> implements AnnotationType {

    /**
     * Type of annotation.
     */
    public static final String TYPE = "Ljavax/ejb/TransactionAttribute;";

    /**
     * Constructor.
     * @param annotationMetadata linked to a class or method metadata
     */
    public JavaxEjbTransactionAttributeVisitor(final T annotationMetadata) {
        super(annotationMetadata);
    }

    /**
     * Visits the end of the annotation. <br>
     * Creates the object and store it.
     */
    @Override
    public void visitEnd() {
        String s = getValue();
        // TYPE annotation
        if (getAnnotationMetadata() != null) {
            if (MANDATORY.name().equals(s)) {
                getAnnotationMetadata().setTransactionAttributeType(MANDATORY);
            } else if (REQUIRED.name().equals(s)) {
                getAnnotationMetadata().setTransactionAttributeType(REQUIRED);
            } else if (REQUIRES_NEW.name().equals(s)) {
                getAnnotationMetadata().setTransactionAttributeType(REQUIRES_NEW);
            } else if (SUPPORTS.name().equals(s)) {
                getAnnotationMetadata().setTransactionAttributeType(SUPPORTS);
            } else if (NOT_SUPPORTED.name().equals(s)) {
                getAnnotationMetadata().setTransactionAttributeType(NOT_SUPPORTED);
            } else if (NEVER.name().equals(s)) {
                getAnnotationMetadata().setTransactionAttributeType(NEVER);
            } else {
                // set default
                getAnnotationMetadata().setTransactionAttributeType(REQUIRED);
            }
        }
    }

    /**
     * @return type of the annotation (its description)
     */
    public String getType() {
        return TYPE;
    }

}
