/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.configurator.visitor;

import org.ow2.util.ee.metadata.common.api.interfaces.IInterceptorExcludeDefaultInterceptors;

/**
 * This class manages the handling of &#64;{@link javax.interceptor.ExcludeDefaultInterceptors}
 * annotation.
 * @param <T> An implementation of IInterceptorExcludeDefaultInterceptors interface.
 * @author Florent Benoit
 */
public class JavaxInterceptorExcludeDefaultInterceptorsVisitor<T extends IInterceptorExcludeDefaultInterceptors> extends
        AbsAnnotationVisitor<T> implements AnnotationType {

    /**
     * Type of annotation.
     */
    public static final String TYPE = "Ljavax/interceptor/ExcludeDefaultInterceptors;";

    /**
     * Constructor.
     * @param annotationMetadata linked to a class or method or field metadata
     */
    public JavaxInterceptorExcludeDefaultInterceptorsVisitor(final T annotationMetadata) {
        super(annotationMetadata);
    }

    /**
     * Visits the end of the annotation.<br>
     * Creates the object and store it.
     */
    @Override
    public void visitEnd() {
        // set flag on method
        getAnnotationMetadata().setExcludeDefaultInterceptors(true);

    }

    /**
     * @return type of the annotation (its description)
     */
    public String getType() {
        return TYPE;
    }

}
