/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.configurator.visitor;

import org.ow2.util.ee.metadata.common.api.interfaces.IHandlerChain;
import org.ow2.util.ee.metadata.common.api.struct.IJwsHandlerChain;
import org.ow2.util.ee.metadata.common.impl.struct.JwsHandlerChain;

/**
 * This class manages the handling of &#64;{@link javax.jws.HandlerChain}
 * annotation.
 * @param <T> An implementation of IHandlerChain interface.
 * @author Guillaume Sauthier
 */
public class JavaxJwsHandlerChainVisitor<T extends IHandlerChain> extends AbsAnnotationVisitor<T> {

    /**
     * Supported type of the annotation visitor.
     */
    public static final String TYPE = "Ljavax/jws/HandlerChain;";

    /**
     * 'file' attribute name.
     */
    private static final String ATTR_FILE = "file";

    /**
     * Parsed HandlerChain metadata.
     */
    private IJwsHandlerChain jwsHandlerChain = null;

    /**
     * Constructor.
     * @param annotationMetadata linked to a class or method metadata
     */
    public JavaxJwsHandlerChainVisitor(final T annotationMetadata) {
        super(annotationMetadata);
        jwsHandlerChain = new JwsHandlerChain();
    }

    /**
     * Visits a primitive value of the annotation.<br>
     * @param name the value name.
     * @param value the actual value, whose type must be {@link Byte},
     *        {@link Boolean}, {@link Character}, {@link Short},
     *        {@link Integer}, {@link Long}, {@link Float}, {@link Double},
     *        {@link String} or {@link org.ow2.util.scan.api.IType}.
     */
    @Override
    public void visit(final String name, final Object value) {
        if (name.equals(ATTR_FILE)) {
            jwsHandlerChain.setFile((String) value);
        }
    }

    /**
     * Visits the end of the annotation.
     */
    public void visitEnd() {
        getAnnotationMetadata().setJwsHandlerChain(jwsHandlerChain);
    }

    /**
     * @return type of the annotation (its description).
     */
    public String getType() {
        return TYPE;
    }
}
