/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.configurator.visitor;

import org.ow2.util.scan.api.IAnnotationVisitor;
import org.ow2.util.scan.api.IType;

/**
 * This class manages the handling of single type like String name().
 * @param <T> the type of annotation metadata.
 * @param <V> the type of class / erasure (for values).
 * @author Florent Benoit
 */
public abstract class ObjectAnnotationVisitor<T, V> extends AbsAnnotationVisitor<T> implements IAnnotationVisitor,
        AnnotationType {

    /**
     * Internal value in the given type.
     */
    private V value = null;


    /**
     * Constructor.
     * @param annotationMetadata linked to a metadata.
     */
    public ObjectAnnotationVisitor(final T annotationMetadata) {
        super(annotationMetadata);
    }


    /**
     * Visits a primitive value of the annotation.
     * @param name the value name.
     * @param value the actual value, whose type must be {@link Byte},
     *        {@link Boolean}, {@link Character}, {@link Short},
     *        {@link Integer}, {@link Long}, {@link Float}, {@link Double},
     *        {@link String} or {@link IType}.
     */
    @Override
    @SuppressWarnings("unchecked")
    public void visit(final String name, final Object value) {
        this.value = (V) value;
    }

    /**
     * @return value of the object
     */
    public V getValue() {
        return this.value;
    }


}
