/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz;

import org.ow2.util.ee.metadata.common.api.ICommonClassMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonFieldMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonMethodMetadata;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.AnnotationType;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.ObjectAnnotationVisitor;

/**
 * @author Loic Albertin
 */
public class JavaxAnnotationManagedBeanVisitor<
        C extends ICommonClassMetadata<C, M, F>,
        M extends ICommonMethodMetadata<C, M, F>,
        F extends ICommonFieldMetadata<C, M, F>> extends ObjectAnnotationVisitor<C, String> implements AnnotationType {
    /**
     * Type of annotation.
     */
    public static final String TYPE = "Ljavax/annotation/ManagedBean;";

    /**
     * Constructor.
     *
     * @param annotationMetadata linked to a metadata.
     */
    public JavaxAnnotationManagedBeanVisitor(final C annotationMetadata) {
        super(annotationMetadata);
    }

    @Override
    public void visitEnd() {
        String value = getValue();
        if (value == null || value.equals("")) {
            // Set the class name if there is no value
            value = getAnnotationMetadata().getJClass().getName();
            if (value.contains("/")) {
                value = value.substring(value.lastIndexOf("/") + 1);
            }
        }
       getAnnotationMetadata().setManagedBeanName(value);
    }

    public String getType() {
        return JavaxAnnotationManagedBeanVisitor.TYPE;
    }
}
