/**
 * OW2 Utilities
 * Copyright (C) 2009-2012 Bull S.A.S.
 * Contact: utilities@ow2.org
 *
 * Licensed  under the  Apache License,  Version 2.0  (the "License");
 * you may not use  this file  except in  compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed  under the  License is distributed on an "AS IS" BASIS,
 * WITHOUT  WARRANTIES OR CONDITIONS  OF ANY KIND, either  express  or
 * implied.
 *
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz;

import org.ow2.util.ee.metadata.common.api.ICommonClassMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonFieldMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonMethodMetadata;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.AbsAnnotationVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.AnnotationType;
import org.ow2.util.scan.api.IAnnotationVisitor;

/**
 * This class manages the handling of &#64;{@link javax.annotation.sql.DataSourceDefinitions} annotation.
 *
 * @param <T> An implementation of IJAnnotationSqlDataSourceDefinition interface.
 *
 * @author Loic Albertin
 */
public class JavaxAnnotationSqlDataSourceDefinitionsVisitor<
    T extends ICommonClassMetadata<T, M, F>,
    M extends ICommonMethodMetadata<T, M, F>,
    F extends ICommonFieldMetadata<T, M, F>>
    extends AbsAnnotationVisitor<T> implements AnnotationType {

    /**
     * Type of annotation.
     */
    public static final String TYPE = "Ljavax/annotation/sql/DataSourceDefinitions;";


    /**
     * Constructor.
     *
     * @param annotationMetadata linked to a class or method metadata
     */
    public JavaxAnnotationSqlDataSourceDefinitionsVisitor(final T annotationMetadata) {
        super(annotationMetadata);
    }

    @Override
    public IAnnotationVisitor visitAnnotation(String name, String desc) {
        if (JavaxAnnotationSqlDataSourceDefinitionVisitor.TYPE.equals(desc)) {
            return new JavaxAnnotationSqlDataSourceDefinitionVisitor<T, M, F>(getAnnotationMetadata());
        }
        return super.visitAnnotation(name, desc);
    }

    /**
     * Visits the end of the annotation. <br>
     * Creates the object and store it.
     */
    @Override
    public void visitEnd() {
     //Noting to do every things are done by JavaxAnnotationSqlDataSourceDefinitionVisitor
    }

    /**
     * @return type of the annotation (its description)
     */
    public String getType() {
        return TYPE;
    }

}
